pub struct Document { /* private fields */ }Expand description
A parsed and rendered markdown document.
Implementations
Sourceimpl Document
Parse markdown source into a Document.
impl Document
Parse markdown source into a Document.
Example
use markless::document::Document;
let doc = Document::parse("# Hello\n\nWorld").unwrap();
assert!(doc.line_count() >= 3); // heading + empty + paragraph + trailing emptySourcepub fn parse_with_layout(source: &str, width: u16) -> Result<Self>
pub fn parse_with_layout(source: &str, width: u16) -> Result<Self>
Errors
Returns an error if markdown parsing fails.
Sourcepub fn parse_with_image_heights(
source: &str,
image_heights: &HashMap<String, usize>,
) -> Result<Self>
pub fn parse_with_image_heights( source: &str, image_heights: &HashMap<String, usize>, ) -> Result<Self>
Errors
Returns an error if markdown parsing fails.
Sourcepub fn parse_with_layout_and_image_heights(
source: &str,
width: u16,
image_heights: &HashMap<String, usize>,
) -> Result<Self>
pub fn parse_with_layout_and_image_heights( source: &str, width: u16, image_heights: &HashMap<String, usize>, ) -> Result<Self>
Errors
Returns an error if markdown parsing fails.
Sourceimpl Document
impl Document
Sourcepub fn from_plain_text(source: &str) -> Self
pub fn from_plain_text(source: &str) -> Self
Create a document from plain text, rendering each line verbatim.
Used for non-markdown files where line breaks should be preserved exactly as they appear in the source.
Sourcepub fn from_hex(file_name: &str, bytes: Vec<u8>) -> Self
pub fn from_hex(file_name: &str, bytes: Vec<u8>) -> Self
Create a hex document from raw bytes.
Stores header lines (heading + size info) in self.lines and raw bytes
in hex_data for lazy hex line generation on demand.
Sourcepub fn line_count(&self) -> usize
pub fn line_count(&self) -> usize
Get the total number of rendered lines.
Sourcepub const fn is_hex_mode(&self) -> bool
pub const fn is_hex_mode(&self) -> bool
Returns true if this document uses lazy hex rendering.
Sourcepub fn headings(&self) -> &[HeadingRef]
pub fn headings(&self) -> &[HeadingRef]
Get all headings for TOC.
Sourcepub const fn mermaid_sources(&self) -> &HashMap<String, String>
pub const fn mermaid_sources(&self) -> &HashMap<String, String>
Get mermaid diagram sources keyed by synthetic image src.
pub fn footnote_line(&self, name: &str) -> Option<usize>
pub fn resolve_internal_anchor(&self, anchor: &str) -> Option<usize>
Sourcepub fn visible_lines(&self, offset: usize, count: usize) -> Vec<&RenderedLine>
pub fn visible_lines(&self, offset: usize, count: usize) -> Vec<&RenderedLine>
Get visible lines for rendering.
Returns lines from offset to offset + count.
Sourcepub fn line_at(&self, index: usize) -> Option<&RenderedLine>
pub fn line_at(&self, index: usize) -> Option<&RenderedLine>
Get a specific rendered line by index.
Sourcepub fn hex_line_content(&self, index: usize) -> Option<String>
pub fn hex_line_content(&self, index: usize) -> Option<String>
Generate the text content for a hex line at the given document index.
Returns the header line content for header indices, or generates the
hex dump line on the fly for hex indices. Returns None if out of range.
Unlike line_at, this does not require the cache to be populated.
Sourcepub fn ensure_hex_lines_for_range(&mut self, range: Range<usize>)
pub fn ensure_hex_lines_for_range(&mut self, range: Range<usize>)
Ensure hex lines are cached for the given document line range.
Generates hex dump lines for the viewport plus a buffer on each side. The range is in terms of overall document line indices (including headers).
Sourcepub fn ensure_highlight_for_range(&mut self, range: Range<usize>)
pub fn ensure_highlight_for_range(&mut self, range: Range<usize>)
Lazily apply syntax highlighting to code blocks intersecting range.